Qwiic Alphanumeric Python Package
=============================================

This package controls individual segments of the 14-segment, alphanumeric displays.
The user can print full strings, adjust brightness, and set the blink rate of their display.
